/*
 Copyright 2012 George Rhoten

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
package com.centralnexus.thermal;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.io.IOException;

import javax.swing.JPanel;

public class AutoResizeImage extends JPanel {
    private static final long serialVersionUID = -5440366595142150447L;

    private Image originalImage;
    private Image scaledImage;
    private int originalImageWidth;
    private int originalImageHeight;

    public AutoResizeImage() {
        super();
    }

    public AutoResizeImage(Image image) throws IOException {
        super();
        setIcon(image);
        setMinimumSize(new Dimension(1, 1));
    }

    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        if (scaledImage != null) {
            scaleImage();
            int panelOffsetX = (this.getWidth() - scaledImage.getWidth(this)) / 2;
            int panelOffsetY = (this.getHeight() - scaledImage.getHeight(this)) / 2;
            g.drawImage(scaledImage, panelOffsetX, panelOffsetY, this);
        }
    }

    public void setIcon(Image image) {
        originalImage = image;
        originalImageWidth = originalImage.getWidth(this);
        originalImageHeight = originalImage.getHeight(this);
        setPreferredSize(new Dimension(originalImageWidth, originalImageHeight));
        setMinimumSize(new Dimension(originalImageWidth/2, originalImageHeight/2));
        scaleImage();
    }
    
    public void scaleImage() {
        if (originalImage != null) {
            int imageWidth = this.originalImageWidth;
            int imageHeight = this.originalImageHeight;
            int panelWidth = this.getWidth();
            int panelHeight = this.getHeight();

            if (panelWidth < imageWidth || panelHeight < imageHeight) {
                float percentScale = Math.min(((float)panelHeight / (float)panelWidth), ((float)imageHeight / (float)imageWidth));
                scaledImage = originalImage.getScaledInstance(Math.max((int)(imageWidth * percentScale), 1), Math.max((int)(imageHeight * percentScale), 1), Image.SCALE_DEFAULT);
            }
            else {
                scaledImage = originalImage;
            }
        }
    }
}